==> alibabacloud_imm20200930-1.29.0.tar.gz: alibabacloud_imm20200930-1.29.0/ChangeLog.md <==
2022-11-15 Version: 1.28.9
- Add story location.
- Support location date clustering.

2022-11-15 Version: 1.28.8
- Set GetDetectVideoLabelsResult to private.
- Set CreateDetectVideoLabelsTask to private.
- Add location for story.

2022-10-28 Version: 1.28.7
- Support Compression.

2022-10-28 Version: 1.28.6
- Automatically generate sdk tasks.

2022-10-28 Version: 1.28.5
- Automatically generate sdk tasks.

2022-10-20 Version: 1.28.4
- Add more features.

2022-10-19 Version: 1.28.3
- Automatically generate sdk tasks.

2022-08-16 Version: 1.28.2
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.28.1
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.28.0
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.27.7
- Automatically generate sdk tasks.

2022-07-20 Version: 1.27.6
- Add Body Detection and Image Splicing API.

2022-07-19 Version: 1.27.5
- Add Body Detection and Image Splicing API.

2022-07-07 Version: 1.27.4
- Add new story APIs.
- Fix Media APIs.
- Add ListRegions.
- Add Code detection APIs.

2022-06-24 Version: 1.27.3
- CreateOfficeConversionTask support TargetURI pattern.

2022-05-31 Version: 1.27.1
- Support new features.

2022-05-31 Version: 1.27.0
- Support new features.

2022-05-05 Version: 1.26.9
- Support new features.

2022-04-26 Version: 1.26.8
- Support new features.

2022-04-13 Version: 1.26.7
- Init latest API version.

2022-01-19 Version: 1.26.6
- Change SimpleQuery aggregation result to string.

2021-12-23 Version: 1.24.0
- Support new APIs.

2021-10-15 Version: 1.0.3
- Support oss Referer.

2021-09-23 Version: 1.0.2
- Fix API standard.

2021-09-03 Version: 1.0.1
- Support metaquery.
- Support weboffice preview edit.

2021-08-26 Version: 1.0.0
- Support metaquery.
- Support weboffice preview edit.

==> alibabacloud_imm20200930-2.0.8.tar.gz: alibabacloud_imm20200930-2.0.8/ChangeLog.md <==
2022-12-13 Version: 1.29.0
- Support Face Searching Api.
- Support Face Comparasion Api.
- Update CompareImageFaces.
- Update backend name.
- Add SimilarImageCluster Apis.
- Remove invalid parameters.

2022-11-15 Version: 1.28.9
- Add story location.
- Support location date clustering.

2022-11-15 Version: 1.28.8
- Set GetDetectVideoLabelsResult to private.
- Set CreateDetectVideoLabelsTask to private.
- Add location for story.

2022-10-28 Version: 1.28.7
- Support Compression.

2022-10-28 Version: 1.28.6
- Automatically generate sdk tasks.

2022-10-28 Version: 1.28.5
- Automatically generate sdk tasks.

2022-10-20 Version: 1.28.4
- Add more features.

2022-10-19 Version: 1.28.3
- Automatically generate sdk tasks.

2022-08-16 Version: 1.28.2
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.28.1
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.28.0
- Add ImageToPDF.
- Add Compress.

2022-08-16 Version: 1.27.7
- Automatically generate sdk tasks.

2022-07-20 Version: 1.27.6
- Add Body Detection and Image Splicing API.

2022-07-19 Version: 1.27.5
- Add Body Detection and Image Splicing API.

2022-07-07 Version: 1.27.4
- Add new story APIs.
- Fix Media APIs.
- Add ListRegions.
- Add Code detection APIs.

2022-06-24 Version: 1.27.3
- CreateOfficeConversionTask support TargetURI pattern.

2022-05-31 Version: 1.27.1
- Support new features.

2022-05-31 Version: 1.27.0
- Support new features.

2022-05-05 Version: 1.26.9
- Support new features.

2022-04-26 Version: 1.26.8
- Support new features.

2022-04-13 Version: 1.26.7
- Init latest API version.

2022-01-19 Version: 1.26.6
- Change SimpleQuery aggregation result to string.

2021-12-23 Version: 1.24.0
- Support new APIs.

2021-10-15 Version: 1.0.3
- Support oss Referer.

2021-09-23 Version: 1.0.2
- Fix API standard.

2021-09-03 Version: 1.0.1
- Support metaquery.
- Support weboffice preview edit.

2021-08-26 Version: 1.0.0
- Support metaquery.
- Support weboffice preview edit.
